/**
 * @description 获取当前市州配置
 * @return
 *     cityName: 'name', // 城市中文名称
 *     cityCode: 'code', // 城市6位区号
 *     cityAbbr: 'abbr', // 城市简写
 *     recordNumber: 'recordNumber', // 备案号
 *     locationCenter: [lat,lng], // 城市地图中心点
 *     favicon: 'favicon.ico', // 浏览器图标
 */
export const getCurrentCityConfig = () => {
  switch (import.meta.env.VITE_CURRENT_CITY) {
    case "yibin":
      return {
        cityName: "宜宾市", // 城市中文名称
        cityCode: "511500", // 城市6位区号
        cityAbbr: "宜宾", // 城市简写
        recordNumber: "蜀ICP备19035032号-36", // 城市备案号
        locationCenter: [104.643, 28.751694], // 城市地图中心点
        favicon: "yibin/favicon.ico", // 浏览器图标
      };
    case "zigong":
      return {
        cityName: "自贡市",
        cityCode: "510300",
        cityAbbr: "zg",
        recordNumber: "蜀ICP备2024053169号-1",
        locationCenter: [104.778001, 29.339399],
        favicon: "zigong/favicon.ico",
      };
    default:
      return {
        cityName: "宜宾市", // 中文名称
        cityCode: "511500", // 6位区号
        cityAbbr: "宜宾", // 简写
        recordNumber: "蜀ICP备19035032号-36", // 备案号
        locationCenter: [104.643, 28.751694], // 地图中心点
        favicon: "yibin/favicon.ico",
      };
  }
};
